@@ -2,11 +2,13 @@
 
 from __future__ import annotations
 
-from botocore.exceptions import ClientError
 from functools import wraps
+
+from botocore.exceptions import ClientError
 import pycognito
 from pycognito import utils
 import requests
+
 from .exceptions import NotAuthorizedError, UnknownError
 
 _DEFAULT_TIMEOUT = 60
@@ -45,7 +47,13 @@ class Auth:
     """Handles authentication for the Schlage WiFi cloud service."""
 
     def __init__(self, username: str, password: str) -> None:
-        """Initializer."""
+        """Initializes an Auth object.
+
+        :param username: The username associated with the Schlage account.
+        :type username: str
+        :param password: The password for the account.
+        :type password: str
+        """
         self.cognito = pycognito.Cognito(
             username=username,
             user_pool_region=USER_POOL_REGION,
@@ -57,17 +65,25 @@ class Auth:
             password=password,
             cognito=self.cognito,
         )
+        self._user_id: str | None = None
 
     @translate_errors
     def authenticate(self):
-        """Performs authentication with AWS."""
+        """Performs authentication with AWS.
+
+        :raise pyschlage.exceptions.NotAuthorizedError: When authentication fails.
+        :raise pyschlage.exceptions.UnknownError: On other errors.
+        """
         self.auth(requests.Request())
 
     @translate_errors
     def request(
         self, method: str, path: str, base_url: str = BASE_URL, **kwargs
     ) -> requests.Response:
-        """Performs a request against the Schlage WiFi cloud service."""
+        """Performs a request against the Schlage WiFi cloud service.
+
+        :meta private:
+        """
         kwargs["auth"] = self.auth
         if "headers" not in kwargs:
             kwargs["headers"] = {}
